pub struct HashMapFormer<K, E, HashMap, Former, ContainerEnd>where
K: Eq + Hash,
HashMap: HashMapLike<K, E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashMap>),{ /* private fields */ }Expand description
Class for forming hashmap-like fields.
Implementations
Sourceimpl<K, E, HashMap, Former, ContainerEnd> HashMapFormer<K, E, HashMap, Former, ContainerEnd>where
K: Eq + Hash,
HashMap: HashMapLike<K, E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashMap>),
impl<K, E, HashMap, Former, ContainerEnd> HashMapFormer<K, E, HashMap, Former, ContainerEnd>where
K: Eq + Hash,
HashMap: HashMapLike<K, E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashMap>),
Sourcepub fn new(
former: Former,
container: Option<HashMap>,
on_end: ContainerEnd,
) -> Self
pub fn new( former: Former, container: Option<HashMap>, on_end: ContainerEnd, ) -> Self
Make a new HashMapFormer. It should be called by a former generated for your structure.
Sourcepub fn replace(self, container: HashMap) -> Self
pub fn replace(self, container: HashMap) -> Self
Set the whole container instead of setting each element individually.