pub struct HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),{ /* private fields */ }Expand description
Class for forming hashset-like fields.
Implementations
Sourceimpl<E, HashSet, Former, ContainerEnd> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),
impl<E, HashSet, Former, ContainerEnd> HashSetFormer<E, HashSet, Former, ContainerEnd>where
E: Eq + Hash,
HashSet: HashSetLike<E> + Default,
ContainerEnd: Fn(&mut Former, Option<HashSet>),
Sourcepub fn new(
former: Former,
container: Option<HashSet>,
on_end: ContainerEnd,
) -> Self
pub fn new( former: Former, container: Option<HashSet>, on_end: ContainerEnd, ) -> Self
Make a new HashSetFormer. It should be called by a former generated for your structure.
Sourcepub fn replace(self, container: HashSet) -> Self
pub fn replace(self, container: HashSet) -> Self
Set the whole container instead of setting each element individually.